<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Dutch_Firefox
</name>

<description>
   <am>Dutch localisation of Firefox</am>
   <ar>Dutch localisation of Firefox</ar>
   <bg>Dutch localisation of Firefox</bg>
   <bn>Dutch localisation of Firefox</bn>
   <ca>Localització de Firefox en Holandès</ca>
   <cs>Dutch localisation of Firefox</cs>
   <da>Hollandsk oversættelse af Firefox</da>
   <de>Niederländische Lokalisierung von Firefox</de>
   <el>Ολλανδικός εντοπισμός του Firefox</el>
   <en>Dutch localisation of Firefox</en>
   <es>Localización Holandesa de Firefox</es>
   <et>Dutch localisation of Firefox</et>
   <eu>Dutch localisation of Firefox</eu>
   <fa>Dutch localisation of Firefox</fa>
   <fil_PH>Dutch localisation of Firefox</fil_PH>
   <fi>Dutch localisation of Firefox</fi>
   <fr>Localisation néerlandaise pour Firefox</fr>
   <he_IL>Dutch localisation of Firefox</he_IL>
   <hi>Dutch localisation of Firefox</hi>
   <hr>Dutch localisation of Firefox</hr>
   <hu>Dutch localisation of Firefox</hu>
   <id>Dutch localisation of Firefox</id>
   <is>Dutch localisation of Firefox</is>
   <it>Localizzazione olandese di Firefox</it>
   <ja_JP>Dutch localisation of Firefox</ja_JP>
   <ja>Dutch localisation of Firefox</ja>
   <kk>Dutch localisation of Firefox</kk>
   <ko>Dutch localisation of Firefox</ko>
   <lt>Dutch localisation of Firefox</lt>
   <mk>Dutch localisation of Firefox</mk>
   <mr>Dutch localisation of Firefox</mr>
   <nb>Dutch localisation of Firefox</nb>
   <nl>Nederlandse lokalisatie van Firefox</nl>
   <pl>Holenderska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Holandês Localização para Firefox</pt_BR>
   <pt>Holandês Localização para Firefox</pt>
   <ro>Dutch localisation of Firefox</ro>
   <ru>Голландская локализация Firefox</ru>
   <sk>Dutch localisation of Firefox</sk>
   <sl>Dutch localisation of Firefox</sl>
   <sq>Dutch localisation of Firefox</sq>
   <sr>Dutch localisation of Firefox</sr>
   <sv>Holländsk lokalisering av Firefox</sv>
   <tr>Firefox'un Flemenkçe yerelleştirmesi</tr>
   <uk>Dutch локалізація Firefox</uk>
   <vi>Dutch localisation of Firefox</vi>
   <zh_CN>Dutch localisation of Firefox</zh_CN>
   <zh_TW>Dutch localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-nl
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-nl
</uninstall_package_names>
</app>
